@@ -75,7 +75,7 @@ ParseThread::~ParseThread()
 	}
 }
 
-ssize_t ParseThread::read(unsigned char *buffer, size_t len)
+int ParseThread::read(unsigned char *buffer, size_t len)
 {
 #ifdef	WIN32
 	DWORD count;
@@ -87,7 +87,7 @@ ssize_t ParseThread::read(unsigned char *buffer, size_t len)
 #endif
 }
 
-void ParseThread::characters(const unsigned char *text, unsigned len)
+void ParseThread::characters(const unsigned char *text, size_t len)
 {
 	const char *vargs[130];
 	const char **args = vargs; 
