@@ -435,6 +435,10 @@ public:
 		DTMF_GENDOWN,	/* peer */
 		DTMF_GENUP,	/* peer */
 		AUDIO_SYNC,	/* peer */
+		AUDIO_RECONNECT,	/* re-invite event... */
+		AUDIO_DISCONNECT,	/* audio holding re-invite */
+		PEER_RECONNECT,		/* peer re-invite notice */
+		PEER_DISCONNECT,	/* peer holding notice */
 		DTMF_GENTONE = DTMF_GENUP,
 
 		// make modes and special timeslot stuff
