@@ -343,6 +343,10 @@ const char *BayonneDriver::assignScript(ScriptImage *img, Line *line)
 	return "selected driver does not support assignments";
 }
 
+void BayonneDriver::reloadDriver(void)
+{
+}
+
 void BayonneDriver::startDriver(void)
 {
 	oink.wait();		// wait for the pig to squeal
@@ -422,6 +426,17 @@ void BayonneDriver::start(void)
 	BayonneSpan::allocate();
 }
 
+void BayonneDriver::reload(void)
+{
+	BayonneDriver *driver = firstDriver;
+
+	while(driver)
+	{
+		driver->reloadDriver();
+		driver = driver->nextDriver;
+	}
+}
+
 void BayonneDriver::stop(void) 
 {
         BayonneDriver *driver = firstDriver;
