@@ -80,15 +80,6 @@ public:
 	 */
 	Libexec();
 
-	/**
-	 * Post a symbol asychrononous event to server.  This sets the
-	 * symbol value, and also generates a \@posted:symname event.
-	 *
-	 * @param id of symbol to post.
-	 * @param value of symbol.
-	 */
-	void postSym(const char *id, const char *value);
-
 	/**
 	 * Get a header record item.
 	 *
@@ -153,9 +144,9 @@ public:
 	 * Send a command through to server and capture result.
 	 *
 	 * @return result code.
-	 * @param text command to send.
-	 * @param buffer for optional query.
-	 * @param size of buffer for optional query.
+	 * @param command to send.
+	 * @param optional query buffer.
+	 * @param optional query size.
 	 */
 	result_t sendCommand(const char *text, char *buffer = NULL, unsigned size = 0);
 
@@ -163,17 +154,24 @@ public:
 	 * Send a result to the server.
 	 *
 	 * @return result code from server.
-	 * @param text result to send.
+	 * @param result to send.
 	 */
 	result_t sendResult(const char *text);
 
+	/**
+	 * Send an error to the server.
+	 *
+	 * @param error msg to send.
+	 */
+	void sendError(const char *msg);
+
 	/**
 	 * Transfer a call.
 	 *
 	 * @return result code from server.
 	 * @param destination to transfer.
 	 */
-	result_t xferCall(const char *destination);
+	result_t xferCall(const char *dest);
 
 	/**
 	 * Replay an audio file.
@@ -181,7 +179,7 @@ public:
 	 * @return result code.
 	 * @param name of file to play.
 	 */
-	result_t replayFile(const char *name);
+	result_t replayFile(const char *file);
 
 	/**
 	 * Replay an audio file from a specified offset.
@@ -190,7 +188,7 @@ public:
 	 * @param name of file to play.
 	 * @param offset to play from.
 	 */
-	result_t replayOffset(const char *name, const char *offset);                                                                            
+	result_t replayOffset(const char *file, const char *offset);                                                                            
 
 	/**
 	 * Record an audio file.
@@ -198,15 +196,15 @@ public:
 	 * @return result code.
 	 * @param name of file to record.
 	 * @param total duration of file.
-	 * @param silence detect timeout in milliseconds.
+	 * @param optional silence detect.
 	 */
-	result_t recordFile(const char *name, timeout_t total, timeout_t silence = 0);
+	result_t recordFile(const char *file, timeout_t duration, timeout_t silence = 0);
 
 	/**
 	 * Play a phrase.
 	 *
 	 * @return result code.
-	 * @param format text of phrase to play.
+	 * @param text of phrase to play.
 	 */
 	result_t speak(const char *format, ...);
 
@@ -216,7 +214,7 @@ public:
 	 * @return result code.
 	 * @param name of tone to play.
 	 * @param duration for tone.
-	 * @param level of tone.
+	 * @param audio level of tone.
 	 */
 	result_t playTone(const char *name, timeout_t duration = 0, unsigned level = 0);
 	result_t playSingleTone(short f1, timeout_t duration, unsigned level = 0);
@@ -229,9 +227,9 @@ public:
 	 * @param name of file to record.
 	 * @param offset to record info.
 	 * @param total duration of file.
-	 * @param silence detect timer in milliseconds.
+	 * @param optional silence detect.
 	 */
-	result_t recordOffset(const char *name, const char *offset, timeout_t total, timeout_t silence = 0);                                                                            
+	result_t recordOffset(const char *file, const char *offset, timeout_t duration, timeout_t silence = 0);                                                                            
 
 	/**
 	 * Erase an audio file.
@@ -239,14 +237,14 @@ public:
 	 * @return result code.
 	 * @param name of file to erase.
 	 */
-	result_t eraseFile(const char *name);
+	result_t eraseFile(const char *file);
 
         /**
          * Move an audio file.
          *
          * @return result code.
-         * @param file1 name of file to move.
-	 * @param file2 destination of move.
+         * @param name of file to move.
+	 * @param destination of move.
          */ 
         result_t moveFile(const char *file1, const char *file2);
 
@@ -266,7 +264,7 @@ public:
 	 * Read a line of input.
 	 *
 	 * @return result code.
-	 * @param buffer for input.
+	 * @param input buffer.
 	 * @param size of input buffer.
 	 * @param timeout for input.
 	 */
@@ -284,6 +282,15 @@ public:
 	result_t addSym(const char *id, const char *value);
 	result_t setSym(const char *id, const char *value);
 	result_t getSym(const char *id, char *buf, unsigned size);
+
+        /**
+         * Post a symbol asychrononous event to server.  This sets the
+         * symbol value, and also generates a @posted:symname event.
+         *
+         * @param id of symbol to post.
+         * @param value of symbol.
+         */  
+	void postSym(const char *id, const char *value);
 };	 
 
 class __EXPORT BayonneTSession : public BayonneSession
@@ -307,6 +314,7 @@ protected:
 	void sysInput(const char *tsid, char *token);
 	void sysHangup(const char *tsid);
 	void sysExit(const char *tsid, char *token);
+	void sysError(const char *tsid, char *token);
 	void sysReturn(const char *tsid, const char *text);
 	void sysXfer(const char *tsid, const char *dest);
 };
