@@ -68,6 +68,7 @@ ScriptInterp(), audio()
 	strcpy(audio.var_position, "00:00:00.000");
 	strcpy(var_bankid, "0");
 	strcpy(var_pid, "none");
+	strcpy(var_joined, "none");
 	var_sid[0] = 0;
 	dtmf_digits = NULL;
 	digit_count = ring_count = 0;
@@ -403,6 +404,8 @@ const char *BayonneSession::getExternal(const char *id)
 		}
 		else if(!stricmp(id, "pid"))
 			return var_pid;
+		else if(!stricmp(id, "joined") || !stricmp(id, "joinid"))
+			return var_joined;
 		else if(!stricmp(id, "callid") || !stricmp(id, "crn"))
 			return var_callid;
 		else if(!stricmp(id, "timeslot"))
@@ -1121,6 +1124,7 @@ final:
 		setConst("session.caller", parent->getSymbol("session.caller"));
 		setConst("session.display", parent->getSymbol("session.display"));
 		strcpy(var_pid, parent->var_sid);
+		strcpy(var_joined, parent->var_sid);
 	}
 	else
 		state.join.answer_timer = 0;
@@ -1362,6 +1366,7 @@ void BayonneSession::makeIdle(void)
 			event.id = seizure;
 		parent->queEvent(&event);
 	}
+	strcpy(var_joined, "none");
 	strcpy(var_pid, "none");
 	starting = false;
 }
