@@ -1224,7 +1224,7 @@ exitkey:
 
 bool BayonneSession::stateJoin(Event *event)
 {
-	Event dtmf_event;
+	Event dtmf_event, hold_event;
 	const char *msg;
 	const char *err;
         event_t pid = PART_DISCONNECT;
@@ -1248,6 +1248,16 @@ bool BayonneSession::stateJoin(Event *event)
 			dtmf = enableDTMF();
                 setSymbol("script.error", "none");
                 return true; 
+	case AUDIO_DISCONNECT:
+		memcpy(&hold_event, event, sizeof(hold_event));
+		hold_event.id = PEER_DISCONNECT;
+		peer->queEvent(&hold_event);
+		return true;
+        case AUDIO_RECONNECT:
+                memcpy(&hold_event, event, sizeof(hold_event));
+                hold_event.id = PEER_RECONNECT;
+                peer->queEvent(&hold_event);
+                return true;
 	case DTMF_KEYDOWN:
 		if(!state.join.dtmf)
 			return true;
@@ -1627,6 +1637,8 @@ seize:
 		purge();
 		BayonneDriver::add(this);
 		type = NONE;
+	case AUDIO_DISCONNECT:
+	case AUDIO_RECONNECT:
 		return false;
 	default:
 		return enterCommon(event);
@@ -1654,6 +1666,9 @@ bool BayonneSession::statePickup(Event *event)
 		goto running;
 	case LINE_DISCONNECT:
 		return true;
+	case AUDIO_DISCONNECT:
+	case AUDIO_RECONNECT:
+		return false;
 	default:
 		return enterCommon(event);
 	}
@@ -1916,6 +1931,9 @@ failure:
 		return true;
 	case LINE_DISCONNECT:
 		return true;
+	case AUDIO_DISCONNECT:
+	case AUDIO_RECONNECT:
+		return false;
 	default:
 		return enterCommon(event);
 	}
@@ -2022,6 +2040,10 @@ bool BayonneSession::stateHangup(Event *event)
 	case MAKE_IDLE:		// ignore since already going idle
 		return true;
 
+	case AUDIO_DISCONNECT:
+	case AUDIO_RECONNECT:
+		return false;
+
 	case LINE_ON_HOOK:
 	case TIMER_EXPIRED:
 		clrAudio();
@@ -2400,6 +2422,9 @@ childerr:
 			}
 
 		return false;
+	case AUDIO_DISCONNECT:
+	case AUDIO_RECONNECT:
+		return true;
 	default:
 		return false;
 	}
