@@ -775,6 +775,11 @@ void Driver::startDriver(void)
 	slog.debug("sip: adding sdp encoding %s", cbuf);
 	info.annotation = strdup(cbuf);
 	eXosip_set_user_agent("GNU Bayonne");
+	
+#ifdef	EXOSIP2_OPTION_SEND_101
+	int val=1;
+	eXosip_set_option(EXOSIP_OPT_DONT_SEND_101, &val); 
+#endif
 
 	slog.debug("sip: bound to port %d", sip_port);
 	msgport->start();
@@ -1611,7 +1616,7 @@ void Driver::run(void)
 	const char *caller = NULL;
 	const char *dialed = NULL;
 	const char *display = NULL;
-	BayonneSession *s;
+	BayonneSession *s = NULL;
 	Session *session;
 	char *k, *v, *l, *p, *line;
 	osip_from_t *from;
@@ -1638,6 +1643,7 @@ void Driver::run(void)
 	uint8 reg_payload;
 	timeout_t expires;
 	unsigned thread = ++instance;
+	time_t now;
 
 	Bayonne::waitLoaded();
 
@@ -2091,6 +2097,236 @@ killit:
 				goto cleanup;
 			}
 			break;
+		case EXOSIP_CALL_REINVITE:
+                        if(!sevent->request)
+                                break;
+                        if(sevent->cid < 1 && sevent->did < 1)
+                                break;
+			session = getCall(sevent->cid);
+			if(!session)
+			{
+				slog.warn("sip: got re-invite for non-existant call");
+				break;
+			}
+
+                        remote_media = NULL;
+                        local_media = NULL;
+                        conn = NULL;
+                        remote_sdp = NULL;
+                        local_sdp = NULL;
+                        display = NULL;
+                        caller = NULL;
+                        dialed = NULL;
+                        local_uri = NULL;
+                        remote_uri = NULL;
+                        from = NULL;
+                        to = NULL;
+                        sdp = NULL;
+                        msg = NULL;
+
+			cp = session->getSymbol("session.ip_public");
+			sdp = newString("", 4096);
+			snprintf(sdp, 4096,
+				"v=0\r\n"
+				"o=bayonne 0 0 IN IP4 %s\r\n"
+				"s=conversation\r\n"
+				"c=IN IP4 %s\r\n"
+				"t=0 0\r\n", cp, cp);
+			
+			mpos = 0;
+			switch(session->info.encoding)
+			{
+			case mulawAudio:
+				data_rtpmap = "PCMU/8000/1";
+				break;
+			case alawAudio:
+				data_rtpmap = "PCMA/8000/1";
+				break;
+			case g721ADPCM:
+				data_rtpmap = "G726-32/8000/1";
+				break;
+			case speexVoice:
+				data_rtpmap = "SPEEX/8000/1";
+				break;
+			case gsmVoice:
+				data_rtpmap = "GSM/8000/1";
+				break;
+			case pcm16Stereo:
+				data_rtpmap = "L16/11025/2";
+				break;
+			case pcm16Mono:
+				switch(session->info.rate)
+				{
+				case 16000:
+					data_rtpmap = "L16/16000/1";
+					break;
+				default:
+					data_rtpmap = "L16/8000/1";
+					break;
+				}
+			default:
+				break;
+			}
+			audio_payload = NULL;
+			remote_sdp = eXosip_get_sdp_info(sevent->request);
+			if(!remote_sdp)
+			{
+				eXosip_lock();
+				eXosip_call_send_answer(sevent->tid, 400, NULL);
+				eXosip_unlock();
+				goto cleanup;
+			}
+			conn = eXosip_get_audio_connection(remote_sdp);
+			remote_media = eXosip_get_audio_media(remote_sdp);
+
+			if(!remote_media)
+			{
+				eXosip_lock();
+				eXosip_call_send_answer(sevent->tid, 415, NULL);
+				eXosip_unlock();
+				goto cleanup;
+			}
+			while(!osip_list_eol(remote_sdp->m_medias, mpos))
+			{
+				remote_media = (sdp_media_t *)osip_list_get(remote_sdp->m_medias, mpos++);
+				if(!remote_media)
+					continue;
+
+				if(!stricmp(remote_media->m_media, "audio") && !audio_payload)
+					audio_media = remote_media;
+				else
+					audio_media = NULL;
+
+				audio_payload = NULL;
+				tmp = NULL;
+				pos = 0;
+
+				while(!osip_list_eol(remote_media->a_attributes, pos))
+				{
+					attr = (sdp_attribute_t *)osip_list_get(remote_media->a_attributes, pos++);
+					if(!attr)
+						continue;
+
+					tmp = attr->a_att_value;
+					if(!tmp)
+						continue;
+
+					if(stricmp(attr->a_att_field, "rtpmap"))
+						continue;
+
+					adp = tmp;
+					tmp = strchr(tmp, ' ');
+					if(!tmp)
+					{
+						adp = NULL;
+						continue;
+					}
+					while(isspace(*tmp))
+						++tmp;
+					if(!strnicmp(tmp, "telephone-event/", 16))
+					{
+						if(session->dtmf_payload)
+							session->dtmf_payload = atoi(adp);
+						continue;
+					}
+					if(!strnicmp(tmp, data_rtpmap, strlen(tmp)))
+					{
+						audio_payload = adp;
+						session->data_payload = atoi(adp);
+					}
+				}
+			}				
+			if(!audio_payload)
+			{
+				eXosip_lock();
+				eXosip_call_send_answer(sevent->tid, 415, NULL);
+				eXosip_unlock();
+				goto cleanup;
+			}
+					
+                        if(session->dtmf_payload)
+                                snprintf(cbuf, sizeof(cbuf),
+                                        "m=audio %d RTP/AVP %d %d\r\n"
+                                        "%s\r\n",
+                                                session->getLocalPort(),
+                                                session->data_payload,
+                                                session->dtmf_payload,
+                                                data_rtpmap);
+                        else
+                                snprintf(cbuf, sizeof(cbuf),
+                                        "m=audio %d RTP/AVP %d\r\n"
+                                        "%s\r\n",
+                                                session->getLocalPort(),
+                                                session->data_payload,
+                                                data_rtpmap);
+
+			addString(sdp, 4096, cbuf);
+                        if(session->dtmf_payload)
+                        {
+                                snprintf(cbuf, sizeof(cbuf),
+                                        "a=rtpmap:%d telephone-events/8000\r\n",                                        
+					session->dtmf_payload);
+                                addString(sdp, 4096, cbuf);
+                        }
+			memset(&event, 0, sizeof(event));
+			if(*conn->c_addr == '0')
+				event.id = AUDIO_DISCONNECT;
+			else
+				event.id = AUDIO_RECONNECT;
+			session->enter();
+			if(!session->rtp || !session->postEvent(&event))
+			{
+				session->leave();
+				eXosip_lock();
+				eXosip_call_send_answer(sevent->tid, 404, NULL);
+				eXosip_unlock();
+				goto cleanup;
+			}
+
+			eXosip_lock();
+			osip_message_header_get_byname(sevent->request, "session-expires", 0, &header);
+			if(header && header->hvalue)
+			{
+				time(&now);
+				expires = osip_atoi(header->hvalue) * 1000;
+				now += (expires / 1000);
+				session->session_timer = now;
+			}
+			else
+			{
+				expires = 0;
+				session->session_timer = 0;
+			}
+			eXosip_unlock();
+
+			if(expires)
+				slog.debug("%s: reconnecting %s:%d; expires=%ld seconds",
+					session->logname, conn->c_addr, atoi(remote_media->m_port), expires / 1000);
+			else
+				slog.debug("%s: reconnecting %s:%d",
+					session->logname, conn->c_addr, atoi(remote_media->m_port));
+			session->rtp->forgetDestination(session->remote_address, session->remote_port);
+			session->remote_address = conn->c_addr;
+			session->remote_port = atoi(remote_media->m_port);
+			session->rtp->addDestination(session->remote_address, session->remote_port);
+			session->leave();
+			eXosip_lock();
+			eXosip_call_build_answer(sevent->tid, 200, &msg);
+			if(!msg)
+			{
+				eXosip_call_send_answer(sevent->tid, 404, NULL);
+				eXosip_unlock();
+				goto cleanup;
+			}
+                        osip_message_set_require(msg, "100rel");
+                        osip_message_set_header(msg, "RSeq", "1");
+                        osip_message_set_body(msg, sdp, strlen(sdp));
+                        osip_message_set_content_type(msg, "application/sdp");
+
+                        eXosip_call_send_answer(sevent->tid, 183, msg);
+
+                        eXosip_unlock();
+			goto cleanup;		
 		case EXOSIP_CALL_INVITE:
 			if(!sevent->request)
 				break;
@@ -2299,6 +2535,17 @@ sip480:
 		
 			session = (Session *)(s);
 
+			session->session_timer = 0;
+			eXosip_lock();
+			osip_message_header_get_byname(sevent->request, "session-expires", 0, &header);
+			if(header && header->hvalue)
+			{
+				time(&now);
+				now += osip_atoi(header->hvalue);
+				session->session_timer = now;
+			}
+			eXosip_unlock();
+
 			session->dtmf_sipinfo = info_negotiate;
 			if(reg->dtmf && !stricmp(reg->dtmf, "info"))
 				session->dtmf_sipinfo = true;
@@ -2386,7 +2633,7 @@ sip480:
 			eXosip_unlock();
 			if(!remote_sdp)
 			{
-				eXosip_unlock();
+				eXosip_lock();
 				eXosip_call_send_answer(sevent->tid, 400, NULL);
 				eXosip_unlock();
 				goto clear;
@@ -2584,6 +2831,7 @@ sip415:
 			eXosip_lock();
 			eXosip_call_send_answer(sevent->tid, 180, NULL);
 			eXosip_unlock();
+			Thread::yield();
 
 			eXosip_lock();
 			eXosip_call_build_answer(sevent->tid, 200, &msg);
