@@ -387,6 +387,7 @@ void RTPStream::runActive(void)
 	unsigned short dtmfoffset = (unsigned short)(info.rate / pps);
 	BayonneSession *joined;
 //	unsigned ecount = 0;
+	time_t now;
 
 	jitter = Driver::sip.jitter;
 	jsend = Driver::sip.jitter;
@@ -425,7 +426,20 @@ void RTPStream::runActive(void)
 			}			
 			dtmfdigits = false;
 		}
+
                 incTimer(info.framing);
+		if(session->session_timer)
+		{
+			time(&now);
+			if(session->session_timer < now)
+			{
+				memset(&event, 0, sizeof(event));
+				event.id = STOP_DISCONNECT;
+				session->queEvent(&event);
+				session->session_timer = 0;
+			}
+		}
+
                 enter();
 
 		// inband detector disabled if dtmf supported elsewhere
