@@ -54,12 +54,6 @@ BayonneDriver(driver, "/bayonne/driver/soundcard", "soundcard", false)
 	if(!active)
 		slog.warn("soundcard/*: device %d unavailable", device);
 
-	if(peer_encoding == Audio::unknownEncoding)
-		peer_encoding = Audio::mulawAudio;
-
-	if(!peer_framing)
-		peer_framing = Audio::getFraming(peer_encoding, 10);
-
 	seize_timer = 0;	// no seizure
 }
 
