@@ -43,14 +43,17 @@ class Session : public Socket, public Thread, public Bayonne
 protected:
 	char buffer[1024];
 	char request[128];
+	char auth[128];
 	const char *req_command;
 	const char *req_path;
 	char *req_query;
+	char *req_auth;
 	regauth_t regs[1024];
 
 	void syncExit(void);
 	void run(void);
 	void sendText(const char *text);
+	void sendAuth(const char *text, const char *ctype = NULL);
 	void sendError(const char *text, const char *ctype = NULL);
 	void sendHeader(const char *ctype = "text/html", unsigned long clen = 0);
 	void xmlrpcFault(int code, const char *text);
@@ -67,6 +70,7 @@ protected:
 	void xmlFault(int code, const char *text);
 	void xmlSuccess(void);
 	void xmlStatus(void);
+	void xmlTraffic(void);
 	void xmlTimeslots(void);
 	void xmlServicelevel(void);
 	void xmlUptime(void);
@@ -79,6 +83,7 @@ protected:
 	void xmlShutdown(void);
 
 	char *urlDecode(char *source);
+	char *b64Decode(char *source);
 
 public:
 	Session(SOCKET so);
