@@ -40,6 +40,54 @@ Session::~Session()
 	terminate();
 }
 
+char *Session::b64Decode(char *src)
+{
+	static const unsigned char alphabet[65] =
+        	"ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";
+
+	char *ret = src;
+	unsigned char *pdst = (unsigned char *)src;
+
+	char decoder[256];
+	int i, bits, c;
+
+        for (i = 0; i < 256; ++i)
+                decoder[i] = 64;
+        for (i = 0; i < 64 ; ++i)
+                decoder[alphabet[i]] = i;
+
+	bits = 1;
+
+	while(*src && !isspace(*src))
+	{
+                c = (unsigned char)(*(src++));
+                if (c == '=')
+                {
+                        if(bits & 0x40000)
+                        {
+                                *(pdst++) = (bits >> 10);
+                                *(pdst++) = (bits >> 2) & 0xff;
+                                break;
+                        }
+                        if (bits & 0x1000)
+                                *(pdst++) = (bits >> 4);
+                        break;
+                }
+                if (decoder[c] == 64)
+                        continue;
+                bits = (bits << 6) + decoder[c];
+                if (bits & 0x1000000)
+                {
+                        *(pdst++) = (bits >> 16);
+                        *(pdst++) = (bits >> 8) & 0xff;
+                        *(pdst++) = (bits & 0xff);
+                        bits = 1;
+                }
+	}
+	*pdst = 0;
+	return ret;
+}
+
 char *Session::urlDecode(char *source)
 {
 	char *ret = source;
@@ -94,12 +142,31 @@ void Session::sendError(const char *text, const char *ctype)
 	sendText("Connection: close\r\n");
 	if(ctype)
 	{
-		snprintf(buffer, sizeof(buffer), "Conection-Type: %s\r\n", ctype);
+		snprintf(buffer, sizeof(buffer), 
+			"Conection-Type: %s\r\n", ctype);
 		sendText(buffer);
 	}
 	sendText("\r\n");
 }
 
+void Session::sendAuth(const char *text, const char *ctype)
+{
+	const char *realm = Service::webservice.getLast("realm");
+        sendText(text);
+        sendText("Server: Bayonne/" VERSION "\r\n");
+        sendText("Connection: close\r\n");
+	snprintf(buffer, sizeof(buffer),
+		"WWW-Authenticate: Basic realm=\"%s\"\r\n", realm);
+	sendText(buffer);
+        if(ctype)
+        {
+                snprintf(buffer, sizeof(buffer),
+                        "Conection-Type: %s\r\n", ctype);
+                sendText(buffer);
+        }
+        sendText("\r\n");
+}
+
 void Session::sendText(const char *text)
 {
 	int flag = 0;
@@ -131,6 +198,7 @@ void Session::sendHeader(const char *ctype, unsigned long clen)
 
 void Session::run(void)
 {
+	const char *secret = Service::webservice.getLast("secret");
 	const char *cp;
 	char *tok;
 	if(readLine(request, sizeof(request), 10000) < 1)
@@ -144,6 +212,7 @@ timeout:
 	req_command = strtok_r(request, " \t\r\n", &tok);
 	req_path = strtok_r(NULL, " \t\r\n", &tok);
 	req_query = NULL;
+	req_auth = NULL;
 	if(req_path)
 		tok = strchr(req_path, '?');
 	else
@@ -159,6 +228,16 @@ timeout:
 		if(readLine(buffer, sizeof(buffer), 10000) < 1)
 			goto timeout;
 
+		if(!strnicmp(buffer, "Authorization: Basic", 20))
+		{
+			cp = buffer + 20;
+			while(isspace(*cp))
+				++cp;
+			setString(auth, sizeof(auth), cp);
+			b64Decode(auth);
+			req_auth = auth;
+		} 
+
 		cp = buffer;
 		while(isspace(*cp))
 			++cp;
@@ -175,6 +254,18 @@ timeout:
 	if(*req_path == '/')
 		++req_path;
 
+	if(!req_auth && secret)
+		xmlFault(401, "Authorization Required");	
+
+	if(secret)
+	{
+		cp = strchr(req_auth, ':');
+		if(cp)
+			++cp;
+		if(cp && stricmp(cp, secret))
+			xmlFault(401, "Authorization Invalid");
+	}
+
 	if(!stricmp(req_command, "post"))
 	{
 		slog.debug("webservice/%d: unknown xmlrpc %s", so, req_path);
@@ -185,6 +276,9 @@ timeout:
 	if(!stricmp(req_path, "status.xml"))
 		xmlStatus();
 
+	if(!stricmp(req_path, "traffic.xml"))
+		xmlTraffic();
+
 	if(!stricmp(req_path, "timeslots.xml"))
 		xmlTimeslots();
 
@@ -227,10 +321,8 @@ timeout:
 	slog.debug("webservice/%d: unknown page %s", so, req_path);
 
 	cp = strrchr(req_path, '.');
-	if(cp && !stricmp(cp, ".xml"))
-		xmlFault(404, "Not Found");	
 
-	sendError("HTTP/1.1 404 Not Found\r\n");
+	xmlFault(404, "Not Found");	
 	syncExit();
 }
 	
