@@ -48,11 +48,18 @@ void Session::xmlFault(int code, const char *string)
 {
 	char msg[96];
 	const char *svc = string;
-	snprintf(msg, sizeof(msg), "HTTP/1.1 %d %s\r\n", code, string);
-	if(code == 401)
-		sendAuth(msg, "text/xml");
+
+	if(code < 600)
+	{
+		snprintf(msg, sizeof(msg), "HTTP/1.1 %d %s\r\n", code, string);
+		if(code == 401)
+			sendAuth(msg, "text/xml");
+		else
+			sendError(msg, "text/xml");
+	}
 	else
-		sendError(msg, "text/xml");
+		sendHeader("text/xml");
+
 	sendText("<?xml version=\"1.0\"?>\r\n");
 	sendText("<serverResponse>\r\n");
 	if(code >= 300 && code <= 500)
